Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(706)

Unified Diff: src/api-natives.cc

Issue 1316933002: [es6] Initial steps towards a correct implementation of IsCallable. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/api.cc ('k') | src/array.js » ('j') | src/objects-debug.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/api-natives.cc
diff --git a/src/api-natives.cc b/src/api-natives.cc
index 5993859710a5e1d4063b6900c5af6d1168e82a97..48c1a87255e19829a3197643ada3be0baabb08bc 100644
--- a/src/api-natives.cc
+++ b/src/api-natives.cc
@@ -491,9 +491,9 @@ Handle<JSFunction> ApiNatives::CreateApiFunction(
map->set_has_indexed_interceptor();
}
// Set instance call-as-function information in the map.
if (!obj->instance_call_handler()->IsUndefined()) {
- map->set_has_instance_call_handler();
+ map->set_is_callable();
}
// Recursively copy parent instance templates' accessors,
« no previous file with comments | « src/api.cc ('k') | src/array.js » ('j') | src/objects-debug.cc » ('J')
@@ -491,9 +491,9 @@ Handle<JSFunction> ApiNatives::CreateApiFunction(
map->set_has_indexed_interceptor();
}
- // Set instance call-as-function information in the map.
+ // Mark instance as callable in the map.
if (!obj->instance_call_handler()->IsUndefined()) {

Powered by Google App Engine
This is Rietveld 408576698